@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -164,8 +164,10 @@ mrp_time_debug_print (mrptime t)
 mrptime
 mrp_time_from_tm (struct tm *tm)
 {
+	/* A portable implementation is available in the notes of the man page
+	 * for timegm */
+
 	gchar   *old_tz;
-	gchar   *tmp;
 	mrptime  t;
 
 	/* This is a hack. Set the timezone to UTC temporarily. */
@@ -176,9 +178,7 @@ mrp_time_from_tm (struct tm *tm)
 
 	/* And set it back. */
 	if (old_tz != NULL && old_tz[0] != '\0') {
-		tmp = g_strconcat ("TZ=", old_tz, NULL);
-		putenv (tmp);
-		g_free (tmp);
+		g_setenv ("TZ", old_tz, TRUE);
 	} else {
 		g_unsetenv ("TZ");
 	}
@@ -308,6 +308,8 @@ mrp_time_from_string (const gchar  *str,
 	/* FIXME: If we want to support reading times other than in UTC,
 	 * implement that here.
 	 */
+	if (!is_utc) {
+	}
 
 	return mrp_time_compose (year,
 				 month,
@@ -1200,7 +1202,6 @@ mrp_time2_set_from_string (MrpTime      *t,
 			   const gchar  *str)
 {
 	gint     len;
-	gboolean is_utc;
 	gboolean is_date;
 	gint     year;
 	gint     month;
@@ -1212,10 +1213,8 @@ mrp_time2_set_from_string (MrpTime      *t,
 	len = strlen (str);
 
 	if (len == 15) { /* floating time */
-		is_utc = FALSE;
 		is_date = FALSE;
 	} else if (len == 16) { /* UTC time, ends in 'Z' */
-		is_utc = TRUE;
 		is_date = FALSE;
 
 		if (str[15] != 'Z') {
@@ -1223,7 +1222,6 @@ mrp_time2_set_from_string (MrpTime      *t,
 		}
 	}
 	else if (len == 8) { /* A date. */
-		is_utc = TRUE;
 		is_date = TRUE;
 	} else {
 		return FALSE;
