@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -900,7 +900,6 @@ planner_gantt_print_data_new (PlannerView     *view,
 	gdouble                max_name_width = 0.0;
 	gdouble                ext;
 	GList       *relations;
-	gdouble      x1;
 	gdouble      y1, y2;
 	mrptime      t1, t2, t0;
 	mrptime      current_time;
@@ -1061,8 +1060,6 @@ planner_gantt_print_data_new (PlannerView     *view,
 			tasks_on_this_page = data->tasks_per_page_without_header;
 		}
 
-		x1 = data->tree_x2;
-
 		/* Loop through the tasks on this row of pages. */
 		for (i = 0; i < tasks_on_this_page; i++) {
 			ptask = l->data;
