@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -508,7 +508,7 @@ resource_view_column_notify_width_cb (GtkWidget           *column,
 				      GParamSpec          *spec,
 				      PlannerResourceView *view)
 {
-	if (GTK_WIDGET_REALIZED (view->priv->tree_view)) {
+	if (gtk_widget_get_realized (GTK_WIDGET (view->priv->tree_view))) {
 		g_signal_emit_by_name (view->priv->tree_view, "columns-changed");
 	}
 }
@@ -866,7 +866,7 @@ resource_view_insert_resource_cb (GtkAction *action,
 
 	cmd = (ResourceCmdInsert*) planner_resource_cmd_insert (view->main_window, NULL);
 
-	if (!GTK_WIDGET_HAS_FOCUS (priv->tree_view)) {
+	if (! gtk_widget_has_focus (GTK_WIDGET (priv->tree_view))) {
 		gtk_widget_grab_focus (GTK_WIDGET (priv->tree_view));
 	}
 
@@ -892,13 +892,10 @@ resource_view_insert_resources_cb (GtkAction *action,
 {
 	PlannerView     *view;
 	PlannerResourceViewPriv *priv;
-	MrpProject      *project;
 
 	view = PLANNER_VIEW (data);
 	priv = PLANNER_RESOURCE_VIEW (view)->priv;
 
-	project = planner_window_get_project (view->main_window);
-
 	/* We only want one of these dialogs at a time. */
 	if (priv->resource_input_dialog) {
 		gtk_window_present (GTK_WINDOW (priv->resource_input_dialog));
@@ -1001,20 +998,14 @@ resource_view_remove_resource_cb (GtkAction *action,
 				  gpointer   data)
 {
 	PlannerView             *view;
-	PlannerResourceViewPriv *priv;
-	MrpProject              *project;
 	GList                   *list, *node;
-	ResourceCmdRemove       *cmd;
 
 	view = PLANNER_VIEW (data);
-	priv = PLANNER_RESOURCE_VIEW (view)->priv;
-
-	project = planner_window_get_project (view->main_window);
 
 	list = resource_view_selection_get_list (view);
 
 	for (node = list; node; node = node->next) {
-		cmd = (ResourceCmdRemove*) resource_cmd_remove (view, MRP_RESOURCE (node->data));
+		resource_cmd_remove (view, MRP_RESOURCE (node->data));
 	}
 
 	g_list_free (list);
@@ -1027,13 +1018,11 @@ resource_view_edit_resource_cb (GtkAction *action,
 				gpointer   data)
 {
 	PlannerView             *view;
-	PlannerResourceViewPriv *priv;
 	MrpResource             *resource;
 	GtkWidget               *dialog;
 	GList                   *list;
 
 	view = PLANNER_VIEW (data);
-	priv = PLANNER_RESOURCE_VIEW (view)->priv;
 
 	list = resource_view_selection_get_list (view);
 
@@ -1569,7 +1558,6 @@ resource_view_cell_name_edited (GtkCellRendererText *cell,
 				gpointer             user_data)
 {
 	PlannerView      *view;
-	PlannerCmd       *cmd;
 	MrpResource      *resource;
 	GtkTreeView      *tree_view;
 	GtkTreeModel     *model;
@@ -1590,7 +1578,7 @@ resource_view_cell_name_edited (GtkCellRendererText *cell,
 
 	g_value_init (&value, G_TYPE_STRING);
 	g_value_set_string (&value, new_text);
-	cmd = resource_cmd_edit_property (view, resource, "name", &value);
+	resource_cmd_edit_property (view, resource, "name", &value);
 	g_value_unset (&value);
 
 	gtk_tree_path_free (path);
@@ -1603,7 +1591,6 @@ resource_view_cell_short_name_edited (GtkCellRendererText *cell,
 				      gpointer             user_data)
 {
 	PlannerResourceView *view;
-	PlannerCmd          *cmd;
 	MrpResource         *resource;
 	GtkTreeView         *tree_view;
 	GtkTreeModel        *model;
@@ -1625,7 +1612,7 @@ resource_view_cell_short_name_edited (GtkCellRendererText *cell,
 
 	g_value_init (&value, G_TYPE_STRING);
 	g_value_set_string (&value, new_text);
-	cmd = resource_cmd_edit_property (PLANNER_VIEW (view), resource, "short_name", &value);
+	resource_cmd_edit_property (PLANNER_VIEW (view), resource, "short_name", &value);
 	g_value_unset (&value);
 
 	gtk_tree_path_free (path);
@@ -1639,7 +1626,6 @@ resource_view_cell_email_edited (GtkCellRendererText *cell,
 				 gpointer             user_data)
 {
 	PlannerView      *view;
-	PlannerCmd       *cmd;
 	MrpResource      *resource;
 	GtkTreeView      *tree_view;
 	GtkTreeModel     *model;
@@ -1661,7 +1647,7 @@ resource_view_cell_email_edited (GtkCellRendererText *cell,
 
 	g_value_init (&value, G_TYPE_STRING);
 	g_value_set_string (&value, new_text);
-	cmd = resource_cmd_edit_property (view, resource, "email", &value);
+	resource_cmd_edit_property (view, resource, "email", &value);
 	g_value_unset (&value);
 
 	gtk_tree_path_free (path);
@@ -1674,7 +1660,6 @@ resource_view_cell_cost_edited (GtkCellRendererText *cell,
 				gpointer             user_data)
 {
 	PlannerView  *view;
-	PlannerCmd   *cmd;
 	MrpResource  *resource;
 	GtkTreeView  *tree_view;
 	GtkTreeModel *model;
@@ -1698,7 +1683,7 @@ resource_view_cell_cost_edited (GtkCellRendererText *cell,
 	fvalue = planner_parse_float (new_text);
 	g_value_init (&value, G_TYPE_FLOAT);
 	g_value_set_float (&value, fvalue);
-	cmd = resource_cmd_edit_property (view, resource, "cost", &value);
+	resource_cmd_edit_property (view, resource, "cost", &value);
 	g_value_unset (&value);
 
 	gtk_tree_path_free (path);
@@ -1711,7 +1696,6 @@ resource_view_cell_type_edited (PlannerCellRendererList *cell,
 				gpointer                 user_data)
 {
 	PlannerView      *view;
-	PlannerCmd       *cmd;
 	MrpResource      *resource;
 	MrpResourceType   type;
 	GtkTreeView      *tree_view;
@@ -1740,7 +1724,7 @@ resource_view_cell_type_edited (PlannerCellRendererList *cell,
 
 	g_value_init (&value, G_TYPE_INT);
 	g_value_set_int (&value, type);
-	cmd = resource_cmd_edit_property (view, resource, "type", &value);
+	resource_cmd_edit_property (view, resource, "type", &value);
 	g_value_unset (&value);
 
 	gtk_tree_path_free (path);
@@ -1796,7 +1780,6 @@ resource_view_cell_group_edited (PlannerCellRendererList *cell,
 				 gpointer                 user_data)
 {
 	PlannerView      *view;
-	PlannerCmd       *cmd;
 	MrpResource      *resource;
 	MrpGroup         *group;
 	GtkTreeView      *tree_view;
@@ -1831,7 +1814,7 @@ resource_view_cell_group_edited (PlannerCellRendererList *cell,
 	g_value_init (&value, MRP_TYPE_GROUP);
 	g_value_set_object (&value, group);
 
-	cmd = resource_cmd_edit_property (view, resource, "group", &value);
+	resource_cmd_edit_property (view, resource, "group", &value);
 	g_value_unset (&value);
 
 	gtk_tree_path_free (path);
@@ -1901,7 +1884,6 @@ resource_view_property_value_edited (GtkCellRendererText *cell,
 				     ColPropertyData     *data)
 {
 	PlannerView        *view;
-	PlannerCmd         *cmd;
 	GtkTreePath        *path;
 	GtkTreeIter         iter;
 	GtkTreeModel       *model;
@@ -1922,9 +1904,9 @@ resource_view_property_value_edited (GtkCellRendererText *cell,
 
 	value = resource_view_custom_property_set_value (property, new_text);
 
-	cmd = resource_cmd_edit_custom_property (view, resource,
-						 property,
-						 &value);
+	resource_cmd_edit_custom_property (view, resource,
+					   property,
+					   &value);
 	g_value_unset (&value);
 
 	gtk_tree_path_free (path);
