@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 #include <config.h>
 #include <math.h>
@@ -27,7 +27,6 @@
 #include <stdlib.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <libgnomeui/gnome-entry.h>
 #include <glade/glade.h>
 #include <gtk/gtk.h>
 #include <libgda/libgda.h>
@@ -317,7 +316,7 @@ show_error_dialog (PlannerPlugin *plugin,
 					 GTK_DIALOG_DESTROY_WITH_PARENT,
 					 GTK_MESSAGE_ERROR,
 					 GTK_BUTTONS_CLOSE,
-					 str);
+					 "%s", str);
 
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
@@ -950,12 +949,9 @@ sql_plugin_retrieve_db_values (PlannerPlugin  *plugin,
 
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
 
-	server_entry = gnome_entry_gtk_entry (
-		GNOME_ENTRY (glade_xml_get_widget (gui, "server_entry")));
-	db_entry = gnome_entry_gtk_entry (
-		GNOME_ENTRY (glade_xml_get_widget (gui, "db_entry")));
-	user_entry = gnome_entry_gtk_entry (
-		GNOME_ENTRY (glade_xml_get_widget (gui, "user_entry")));
+	server_entry   = glade_xml_get_widget (gui, "server_entry");
+	db_entry       = glade_xml_get_widget (gui, "db_entry");
+	user_entry     = glade_xml_get_widget (gui, "user_entry");
 	password_entry = glade_xml_get_widget (gui, "password_entry");
 
 	str = planner_conf_get_string (CONF_SERVER, NULL);
