@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -183,6 +183,7 @@ static void            task_dialog_new_pred_cancel_clicked_cb     (GtkWidget
 								   GtkWidget               *dialog);
 static void            task_dialog_update_sensitivity             (DialogData              *data);
 static void            task_dialog_update_title                   (DialogData              *data);
+extern gchar *         get_wbs_from_task                          (MrpTask *task);
 
 
 
@@ -290,7 +291,7 @@ task_dialog_setup_option_menu (GtkWidget     *option_menu,
 	for (str = str1, i = 0; str != NULL; str = va_arg (args, gpointer), i++) {
 		menu_item = gtk_menu_item_new_with_label (str);
 		gtk_widget_show (menu_item);
-		gtk_menu_append (GTK_MENU (menu), menu_item);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 
 		type = va_arg (args, gint);
 
@@ -350,56 +351,55 @@ task_dialog_option_menu_set_selected (GtkWidget *option_menu, gint data)
 #endif
 
 static void
-task_dialog_task_combo_select_child_cb (GtkList   *list,
-					GtkWidget *item,
-					GtkCombo  *combo)
-{
-	MrpTask *task;
-
-	task = g_object_get_data (G_OBJECT (item), "task");
-	g_object_set_data (G_OBJECT (combo), "selected_task", task);
-}
-
-static void
-task_dialog_setup_task_combo (GtkCombo *combo,
+task_dialog_setup_task_combo (GtkComboBoxEntry *combo,
 			      GList    *tasks)
 {
-	GList       *strings;
-	GList       *children;
-	GList       *l;
-	const gchar *name;
+	GtkListStore *store;
+	GtkTreeIter iter;
+	GList        *l;
+	const gchar  *name;
 
 	if (tasks == NULL) {
 		return;
 	}
 
-	strings = NULL;
+	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_POINTER);
 	for (l = tasks; l; l = l->next) {
+		GString *task_label;
+		gchar *wbs;
+
+		gtk_list_store_append (store, &iter);
+		task_label = g_string_new( NULL);
+
+		wbs = get_wbs_from_task (l->data);
+		if (wbs != NULL && wbs[0] != 0)
+			g_string_append_printf (task_label, "%s ", wbs);
+		g_free(wbs);
+
 		name = mrp_task_get_name (l->data);
-		if (name == NULL || name[0] == 0) {
-			strings = g_list_prepend (strings,
-						  _("(No name)"));
+		if (name != NULL && name[0] != 0)
+			g_string_append (task_label, name);
+
+		if (task_label->len == 0) {
+			gtk_list_store_set (store, &iter,
+			                    0, _("(No name)"),
+			                    1, l->data,
+			                    -1);
 		} else {
-			strings = g_list_prepend (strings, (gchar*) name);
+			gtk_list_store_set (store, &iter,
+			                    0, task_label->str,
+			                    1, l->data,
+			                    -1);
 		}
+		g_string_free(task_label, TRUE);
 	}
 
-	strings = g_list_reverse (strings);
-	gtk_combo_set_popdown_strings (combo, strings);
-	g_list_free (strings);
+	gtk_combo_box_set_model (GTK_COMBO_BOX (combo),
+	                         GTK_TREE_MODEL (store));
 
-	g_object_set_data (G_OBJECT (combo), "selected_task", tasks->data);
+	gtk_combo_box_entry_set_text_column (combo, 0);
 
-	children = GTK_LIST (combo->list)->children;
-	for (l = children; l; l = l->next) {
-		g_object_set_data (G_OBJECT (l->data), "task", tasks->data);
-		tasks = tasks->next;
-	}
-
-	g_signal_connect (combo->list,
-			  "select-child",
-			  G_CALLBACK (task_dialog_task_combo_select_child_cb),
-			  combo);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
 static gboolean
@@ -1072,7 +1072,6 @@ static PlannerCmd *
 task_cmd_edit_note (DialogData  *data,
 		    const gchar *focus_in_note)
 {
-	PlannerCmd      *cmd_base;
 	TaskCmdEditNote *cmd;
 	gchar           *note;
 
@@ -1083,13 +1082,11 @@ task_cmd_edit_note (DialogData  *data,
 		return NULL;
 	}
 
-	cmd_base = planner_cmd_new (TaskCmdEditNote,
-				    _("Edit task note"),
-				    task_cmd_edit_note_do,
-				    task_cmd_edit_note_undo,
-				    task_cmd_edit_note_free);
-
-	cmd = (TaskCmdEditNote *) cmd_base;
+	cmd = (TaskCmdEditNote *) planner_cmd_new (TaskCmdEditNote,
+						   _("Edit task note"),
+						   task_cmd_edit_note_do,
+						   task_cmd_edit_note_undo,
+						   task_cmd_edit_note_free);
 
 	cmd->property = g_strdup ("note");
 	cmd->task = g_object_ref (data->task);
@@ -1098,9 +1095,9 @@ task_cmd_edit_note (DialogData  *data,
 	cmd->note = note;
 
 	planner_cmd_manager_insert_and_do (planner_window_get_cmd_manager (data->main_window),
-					   cmd_base);
+					   (PlannerCmd *) cmd);
 
-	return cmd_base;
+	return (PlannerCmd *) cmd;
 }
 
 
@@ -1168,7 +1165,6 @@ task_dialog_name_focus_out_cb (GtkWidget     *w,
 {
 	gchar        *focus_in_name;
 	GValue        value = { 0 };
-	PlannerCmd   *cmd;
 
 	g_assert (MRP_IS_TASK (data->task));
 
@@ -1177,8 +1173,8 @@ task_dialog_name_focus_out_cb (GtkWidget     *w,
 	g_value_init (&value, G_TYPE_STRING);
 	g_value_set_string (&value, focus_in_name);
 
-	cmd = task_cmd_edit_property_focus (data->main_window,
-					    data->task, "name", &value);
+	task_cmd_edit_property_focus (data->main_window,
+				      data->task, "name", &value);
 
 	g_free (focus_in_name);
 
@@ -1337,7 +1333,6 @@ task_dialog_work_focus_out_cb (GtkWidget     *w,
 	gint          current_work;
 	gint          focus_in_work;
 	GValue        value = { 0 };
-	PlannerCmd   *cmd;
 
 	g_object_get (data->task, "project", &project, NULL);
 
@@ -1356,9 +1351,9 @@ task_dialog_work_focus_out_cb (GtkWidget     *w,
 	g_value_init (&value, G_TYPE_INT);
 	g_value_set_int (&value, focus_in_work);
 
-	cmd = task_cmd_edit_property_focus (data->main_window,
-					    data->task, "work",
-					    &value);
+	task_cmd_edit_property_focus (data->main_window,
+				      data->task, "work",
+				      &value);
 
 	return FALSE;
 }
@@ -1416,7 +1411,6 @@ task_dialog_duration_focus_out_cb (GtkWidget     *w,
 	gint          current_duration;
 	gint          focus_in_duration;
 	GValue        value = { 0 };
-	PlannerCmd   *cmd;
 
 	g_object_get (data->task, "project", &project, NULL);
 
@@ -1435,9 +1429,9 @@ task_dialog_duration_focus_out_cb (GtkWidget     *w,
 	g_value_init (&value, G_TYPE_INT);
 	g_value_set_int (&value, focus_in_duration);
 
-	cmd = task_cmd_edit_property_focus (data->main_window,
-					    data->task, "duration",
-					    &value);
+	task_cmd_edit_property_focus (data->main_window,
+				      data->task, "duration",
+				      &value);
 
 	return FALSE;
 }
@@ -1562,7 +1556,6 @@ task_dialog_complete_focus_out_cb (GtkWidget     *w,
 	guint         current_complete;
 	guint         focus_in_complete;
 	GValue        value = { 0 };
-	PlannerCmd   *cmd;
 
 	g_assert (MRP_IS_TASK (data->task));
 
@@ -1581,8 +1574,8 @@ task_dialog_complete_focus_out_cb (GtkWidget     *w,
 	g_value_init (&value, G_TYPE_UINT);
 	g_value_set_uint (&value, focus_in_complete);
 
-	cmd = task_cmd_edit_property_focus (data->main_window,
-					    data->task, "percent_complete", &value);
+	task_cmd_edit_property_focus (data->main_window,
+				      data->task, "percent_complete", &value);
 
 	return FALSE;
 }
@@ -1653,7 +1646,7 @@ task_dialog_priority_focus_out_cb (GtkWidget     *w,
 	gint          current_priority;
 	gint          focus_in_priority;
 	GValue        value = { 0 };
-	PlannerCmd   *cmd;
+	PlannerCmd __attribute__ ((unused))  *cmd;
 
 	g_assert (MRP_IS_TASK (data->task));
 
@@ -1749,11 +1742,10 @@ task_dialog_note_focus_out_cb (GtkWidget     *w,
 			       DialogData    *data)
 {
 	gchar        *focus_in_note;
-	PlannerCmd   *cmd;
 
 	focus_in_note = g_object_get_data (G_OBJECT (data->task),"focus_in_note");
 
-	cmd = task_cmd_edit_note (data, focus_in_note);
+	task_cmd_edit_note (data, focus_in_note);
 
 	if (g_getenv ("PLANNER_DEBUG_UNDO_TASK")) {
 		gchar *note;
@@ -1906,7 +1898,7 @@ task_dialog_predecessor_dialog_new (MrpTask       *task,
 
 	tasks = mrp_project_get_all_tasks (project);
 	tasks = g_list_remove (tasks, task);
-	task_dialog_setup_task_combo (GTK_COMBO (w), tasks);
+	task_dialog_setup_task_combo (GTK_COMBO_BOX_ENTRY (w), tasks);
 
 	w = glade_xml_get_widget (glade, "type_optionmenu");
 	g_object_set_data (G_OBJECT (dialog), "type_optionmenu", w);
@@ -1947,10 +1939,11 @@ task_dialog_new_pred_ok_clicked_cb (GtkWidget *button,
 	GtkWidget     *w;
 	GError        *error = NULL;
 	MrpTask       *task_main;
-	MrpTask       *new_task_pred;
+	MrpTask       *new_task_pred = NULL;
 	MrpProject    *project;
 	gint           lag;
 	gint           pred_type;
+	GtkTreeIter    iter;
 	const gchar   *str;
 
 	main_window = g_object_get_data (G_OBJECT (dialog), "main_window");
@@ -1970,7 +1963,11 @@ task_dialog_new_pred_ok_clicked_cb (GtkWidget *button,
 	/* Predecessor task. */
 	w = g_object_get_data (G_OBJECT (dialog), "predecessor_combo");
 
-	new_task_pred = g_object_get_data (G_OBJECT (w), "selected_task");
+	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (w), &iter)) {
+		gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (w)),
+				    &iter, 1, &new_task_pred, -1);
+	}
+
 	if (new_task_pred == NULL) {
 		g_warning (_("Can't add new predecessor. No task selected!"));
                 return;
@@ -2083,7 +2080,6 @@ task_dialog_pred_cell_edited (GtkCellRendererText *cell,
 	GtkTreePath             *path;
 	GtkTreeIter              iter;
 	GtkTreeModel            *model;
-	MrpProject              *project;
 	MrpRelation             *relation;
 	MrpTask                 *task_main;
 	MrpTask                 *task_pred;
@@ -2104,8 +2100,6 @@ task_dialog_pred_cell_edited (GtkCellRendererText *cell,
 							     &iter));
 	task_main = data->task;
 
-	project = mrp_object_get_project (MRP_OBJECT (task_main));
-
 	relation = mrp_task_get_relation (task_main, task_pred);
 	lag = mrp_relation_get_lag (relation) / (60*60);
 	type = mrp_relation_get_relation_type (relation);
