@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 /* FIXME: This code needs a SERIOUS clean-up. */
@@ -231,14 +231,12 @@ usage_chart_class_init (PlannerUsageChartClass * class)
 	GObjectClass      *o_class;
 	GtkObjectClass    *object_class;
 	GtkWidgetClass    *widget_class;
-	GtkContainerClass *container_class;
 
 	parent_class = g_type_class_peek_parent (class);
 
 	o_class = (GObjectClass *) class;
 	object_class = (GtkObjectClass *) class;
 	widget_class = (GtkWidgetClass *) class;
-	container_class = (GtkContainerClass *) class;
 
 	o_class->set_property = usage_chart_set_property;
 	o_class->get_property = usage_chart_get_property;
@@ -534,15 +532,12 @@ planner_usage_chart_can_zoom (PlannerUsageChart *chart,
 void
 planner_usage_chart_zoom_to_fit (PlannerUsageChart *chart)
 {
-	PlannerUsageChartPriv *priv;
 	gdouble                 t;
 	gdouble                 zoom;
 	gdouble                 alloc;
 
 	g_return_if_fail (PLANNER_IS_USAGE_CHART (chart));
 
-	priv = chart->priv;
-
 	t = usage_chart_get_width (chart);
 	if (t == -1) {
 		return;
@@ -656,7 +651,7 @@ usage_chart_realize (GtkWidget *widget)
 	colormap = gtk_widget_get_colormap (canvas);
 	gdk_color_white (colormap, &style->bg[GTK_STATE_NORMAL]);
 	gtk_widget_set_style (canvas, style);
-	gtk_style_unref (style);
+	g_object_unref (style);
 
 	usage_chart_set_zoom (chart, priv->zoom);
 }
@@ -664,10 +659,6 @@ usage_chart_realize (GtkWidget *widget)
 static void
 usage_chart_unrealize (GtkWidget *widget)
 {
-	PlannerUsageChart *chart;
-
-	chart = PLANNER_USAGE_CHART (widget);
-
 	if (GTK_WIDGET_CLASS (parent_class)->unrealize) {
 		GTK_WIDGET_CLASS (parent_class)->unrealize (widget);
 	}
@@ -697,15 +688,12 @@ static void
 usage_chart_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 {
 	PlannerUsageChart *chart;
-	gboolean            height_changed;
-
-	height_changed = widget->allocation.height != allocation->height;
 
 	GTK_WIDGET_CLASS (parent_class)->size_allocate (widget, allocation);
 
 	chart = PLANNER_USAGE_CHART (widget);
 
-	if (GTK_WIDGET_MAPPED (chart)) {
+	if (gtk_widget_get_mapped (GTK_WIDGET (chart))) {
 		usage_chart_reflow_now (chart);
 	}
 }
@@ -876,7 +864,7 @@ usage_chart_reflow_idle (PlannerUsageChart *chart)
 static void
 usage_chart_reflow_now (PlannerUsageChart *chart)
 {
-	if (!GTK_WIDGET_MAPPED (chart)) {
+	if (! gtk_widget_get_mapped (GTK_WIDGET (chart))) {
 		return;
 	}
 
@@ -886,7 +874,7 @@ usage_chart_reflow_now (PlannerUsageChart *chart)
 static void
 usage_chart_reflow (PlannerUsageChart *chart, gboolean height_changed)
 {
-	if (!GTK_WIDGET_MAPPED (chart)) {
+	if (! gtk_widget_get_mapped (GTK_WIDGET (chart))) {
 		return;
 	}
 
@@ -1077,12 +1065,11 @@ usage_chart_build_tree (PlannerUsageChart * chart)
 	PlannerUsageChartPriv *priv;
 	GtkTreeIter             iter;
 	GtkTreePath            *path;
-	TreeNode               *node;
 	GtkTreeIter             child;
 
 	priv = chart->priv;
 
-	path = gtk_tree_path_new_root ();
+	path = gtk_tree_path_new_first ();
 	if (!gtk_tree_model_get_iter (chart->priv->model, &iter, path)) {
 		gtk_tree_path_free (path);
 		return;
@@ -1098,7 +1085,7 @@ usage_chart_build_tree (PlannerUsageChart * chart)
 							 &iter);
 
 		path = gtk_tree_model_get_path (priv->model, &iter);
-		node = usage_chart_insert_resource (chart, path, res);
+		usage_chart_insert_resource (chart, path, res);
 		gtk_tree_path_free (path);
 		if (gtk_tree_model_iter_children (priv->model, &child, &iter)) {
 			do {
@@ -1108,9 +1095,9 @@ usage_chart_build_tree (PlannerUsageChart * chart)
 					 &child);
 				path = gtk_tree_model_get_path (priv->model,
 								&child);
-				node = usage_chart_insert_assignment (chart,
-								       path,
-								       assign);
+				usage_chart_insert_assignment (chart,
+							       path,
+							       assign);
 				gtk_tree_path_free (path);
 			} while (gtk_tree_model_iter_next
 				 (priv->model, &child));
@@ -1382,7 +1369,6 @@ usage_chart_row_inserted (GtkTreeModel *model,
 			   gpointer      data)
 {
 	PlannerUsageChart     *chart;
-	PlannerUsageChartPriv *priv;
 	gboolean                free_path = FALSE;
 	gboolean                free_iter = FALSE;
 	MrpResource            *res;
@@ -1390,7 +1376,6 @@ usage_chart_row_inserted (GtkTreeModel *model,
 	TreeNode               *node = NULL;
 
 	chart = data;
-	priv = chart->priv;
 
 	if (path == NULL) {
 		path = gtk_tree_model_get_path (model, iter);
